==> react-native-wonder-amap-0.0.31.tgz: package/lib/components/MapView.js <==
import React, {Component} from 'react';
import {
    View,
    NativeEventEmitter,
    NativeAppEventEmitter,
    DeviceEventEmitter,
    NativeModules,
    ViewPropTypes,
    UIManager,
    Platform,
    requireNativeComponent,
    findNodeHandle
} from 'react-native';
import PropTypes from 'prop-types';

class AMapView extends Component {

    static propTypes = {
        userTrackingMode: PropTypes.string, // none | follow | followHeading
        showUserLocation: PropTypes.bool,
        showTraffic: PropTypes.bool
    };

    static defaultProps = {
        userTrackingMode: 'none',
        showUserLocation: false,
        showTraffic: false
    };

    runCommand(name, args = []) {
        switch (Platform.OS) {
            case 'android':
                UIManager.dispatchViewManagerCommand(findNodeHandle(this.amap), UIManager['AMap'].Commands[name], args);
                break;
            case 'ios':
                let x = NativeModules['AMapManager'];
                let y = x[name];
                NativeModules['AMapManager'][name](findNodeHandle(this.amap), ...args);
                break;
            default:
                break;
        }
    }

    render() {
        return (<AMap ref={ref => this.amap = ref} {...this.props}/>);
    }

    setCenterCoordinate(coordinate, edgeInsets={top: 0, left: 0, bottom: 0, right: 0}, animated = true) {
        this.runCommand('setCenterCoordinate', [coordinate, edgeInsets, animated]);
    }

    reCenter(edgeInsets = {top: 0, left: 0, bottom: 0, right: 0}, animated = true) {
        this.runCommand('reCenter', [edgeInsets, animated]);
    }

    showAnnotations(annotations) {
        this.runCommand('showAnnotations', [annotations]);
    }

    addAnnotation(annotation) {
        this.runCommand('addAnnotation', [annotation]);
    }

    addAnnotations(annotations) {
        this.runCommand('addAnnotations', [annotations]);
    }

    removeAnnotation(annotation) {
        this.runCommand('removeAnnotation', [annotation]);
    }

    removeAnnotations(annotations) {
        this.runCommand('removeAnnotations', [annotations]);
    }

    clearAnnotations() {
        this.runCommand('clearAnnotations');
    }

    selectAnnotation(annotation) {
        this.runCommand('selectAnnotation', [annotation]);
    }

    deselectAnnotation(annotation) {
        this.runCommand('deselectAnnotation', [annotation]);
    }

    naviTo(destination) {
        this.runCommand('naviTo', [destination]);
    }

    naviFromTo(source, destination) {
        this.runCommand('naviFromTo', [source, destination]);
    }
}

const AMap = requireNativeComponent('AMap', {
    name: 'MapView',
    propTypes: {
        userTrackingMode: PropTypes.string,
        showUserLocation: PropTypes.bool,
        showTraffic: PropTypes.bool,
        ...View.propTypes
    }
});
const {AMapManager, AMapModule, AMapNaviManager} = NativeModules;
const AMapEventEmitter = (() => {
    switch (Platform.OS) {
        case 'android':
            return NativeAppEventEmitter;
        case 'ios':
            const {AMapEventEmitter: _AMapEventEmitter} = NativeModules;
            return new NativeEventEmitter(_AMapEventEmitter);
        default:
            return undefined;
    }
})();

export {AMapView, AMapModule, AMapEventEmitter};

==> react-native-wonder-amap-0.0.36.tgz: package/lib/components/MapView.js <==
import React, {Component} from 'react';
import {
    View,
    NativeEventEmitter,
    NativeAppEventEmitter,
    DeviceEventEmitter,
    NativeModules,
    ViewPropTypes,
    UIManager,
    Platform,
    requireNativeComponent,
    findNodeHandle,
    PixelRatio
} from 'react-native';
import PropTypes from 'prop-types';

class AMapView extends Component {

    static propTypes = {
        userTrackingMode: PropTypes.string, // none | follow | followHeading
        showUserLocation: PropTypes.bool,
        showTraffic: PropTypes.bool
    };

    static defaultProps = {
        userTrackingMode: 'none',
        showUserLocation: false,
        showTraffic: false
    };

    mapEdgeInsets = {top: 0, left: 0, bottom: 0, right: 0};

    runCommand(name, args = []) {
        switch (Platform.OS) {
            case 'android':
                UIManager.dispatchViewManagerCommand(findNodeHandle(this.amap), UIManager['AMap'].Commands[name], args);
                break;
            case 'ios':
                let x = NativeModules['AMapManager'];
                let y = x[name];
                NativeModules['AMapManager'][name](findNodeHandle(this.amap), ...args);
                break;
            default:
                break;
        }
    }

    render() {
        return (<AMap ref={ref => this.amap = ref} {...this.props}/>);
    }

    setCenterWithEdgeInsets(coordinate, edgeInsets, animated = true) {
        edgeInsets && this._setMapEdgeInsets(edgeInsets);
        this.runCommand('setCenterWithEdgeInsets', [coordinate, this.mapEdgeInsets, animated]);
    }

    reCenterWithEdgeInsets(edgeInsets, animated = true) {
        edgeInsets && this._setMapEdgeInsets(edgeInsets);
        this.runCommand('reCenterWithEdgeInsets', [this.mapEdgeInsets, animated]);
    }

    showAnnotations(annotations) {
        this.runCommand('showAnnotations', [annotations]);
    }

    /**
     * [addAnnotation description]
     * @param {[type]} annotation --
     * {
     *      id: number,
     *      coordinate:
     *      {
     *          longitude: number,
     *          latitude: number
     *      },
     *      image: string(Base64),
     *      type: string,
     *      title: string
     * }
     */
    addAnnotation(annotation) {
        this.runCommand('addAnnotation', [annotation]);
    }

    addAnnotations(annotations) {
        this.runCommand('addAnnotations', [annotations]);
    }

    removeAnnotation(annotation) {
        this.runCommand('removeAnnotation', [annotation]);
    }

    removeAnnotations(annotations) {
        this.runCommand('removeAnnotations', [annotations]);
    }

    clearAnnotations() {
        this.runCommand('clearAnnotations');
    }

    selectAnnotation(annotation) {
        this.runCommand('selectAnnotation', [annotation]);
    }

    deselectAnnotation(annotation) {
        this.runCommand('deselectAnnotation', [annotation]);
    }

    naviTo(destination) {
        this.runCommand('naviTo', [destination]);
    }

    naviFromTo(source, destination) {
        this.runCommand('naviFromTo', [source, destination]);
    }

    _setMapEdgeInsets(edgeInsets) {
        switch (Platform.OS) {
            case 'android':
                const {top: _top = 0, bottom: _bottom = 0, left: _left = 0, right: _right = 0} = edgeInsets;
                this.mapEdgeInsets = {
                    top: PixelRatio.getPixelSizeForLayoutSize(_top),
                    bottom: PixelRatio.getPixelSizeForLayoutSize(_bottom),
                    left: PixelRatio.getPixelSizeForLayoutSize(_left),
                    right: PixelRatio.getPixelSizeForLayoutSize(_right)
                };
                break;
            case 'ios':
                this.mapEdgeInsets = edgeInsets;
                break;
            default:
                break;
        }
    }
}

const AMap = requireNativeComponent('AMap', {
    name: 'MapView',
    propTypes: {
        userTrackingMode: PropTypes.string,
        showUserLocation: PropTypes.bool,
        showTraffic: PropTypes.bool,
        center: PropTypes.object, // {longitude: number, latitude: number}
        edgeInsets: PropTypes.object, // {top: number, bottom: number, left: number, right: number}
        zoom: PropTypes.number,
        centerAndZoom: PropTypes.object, // {center: {longitude: number, latitude: number}, zoom: number}
        ...View.propTypes
    }
});
const {AMapManager, AMapModule, AMapNaviManager} = NativeModules;
const AMapEventEmitter = (() => {
    switch (Platform.OS) {
        case 'android':
            return NativeAppEventEmitter;
        case 'ios':
            const {AMapEventEmitter: _AMapEventEmitter} = NativeModules;
            return new NativeEventEmitter(_AMapEventEmitter);
        default:
            return undefined;
    }
})();

export {AMapView, AMapModule, AMapEventEmitter};
